@@ -33,3 +33,10 @@ class TestModel(unittest.TestCase):
         results = self.deepar.results(forecasts)
         res = self.deepar.metrics(results)
         self.assertLess(res['mase']['bottom'], 2.8)
+
+    def test_wall_time(self):
+        model = self.deepar.train(epochs=10)
+        forecasts = self.deepar.predict(model)
+        results = self.deepar.results(forecasts)
+        res = self.deepar.metrics(results)
+        self.assertLess(res['wall_time']['wall_time_total'], 50)
