@@ -25,3 +25,9 @@ class TestModel(unittest.TestCase):
         forecasts = self.mint.train()
         res = self.mint.results(forecasts)
         self.assertTrue(res.shape == (1, self.n, self.s))
+
+    def test_results_interval(self):
+        forecasts = self.mint.train()
+        results = self.mint.results(forecasts)
+        res = self.mint.metrics(results)
+        self.assertLess(res['mase']['bottom'], 2.5)
